.. _outline_:

****************
nexoclom Outline
****************

* configure_model.py

    * Functions

        * configfile()
        * set_up_output_tables()
        * configure_model()

    * Classes

* Input.py

    * Functions

    * Classes

        * Geometry
        * StickingInfo
        * Forces
        * SpatialDist
        * SpeedDist
        * AngularDist
        * Options

* input_classes.py

    * Functions

    * Classes

* modeldriver.py

    * Functions

        * modeldriver()
        * delete_files()

    * Classes

* Output.py

    * Functions

    * Classes

        * Output

* satellite_initial_positions.py

    * Functions

    * Classes

* LossInfo.py

    * Functions

    * Classes

        * LossInfo

* State.py

    * Functions

    * Classes

* bouncepackets.py

    * Functions

    * Classes

* rk5.py

    * Functions

    * Classes

* source_distribution.py

    * Functions

    * Classes

* xyz_to_magcoord.py

    * Functions

    * Classes

* ModelResults.py

    * Functions

    * Classes

        * ModelResult

* LOSResult.py

    * Functions

    * Classes

        * LOSResult(ModelResult)

* produce_image.py

    * Functions

    * Classes

        * ModelImage(ModelResult)

* IDLout.py

    * Functions

    * Classes

        * IDLout

* __init__.py

    * Functions

    * Classes

